

.. _sphx_glr_auto_examples_parallel:

.. _parallel_examples:

Parallel examples
-----------------

Examples demoing more advanced parallel patterns.



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows the simplest usage of the Dask backend on your local machine.">

.. only:: html

  .. image:: /auto_examples/parallel/images/thumb/sphx_glr_distributed_backend_simple_thumb.png
    :alt:

  :ref:`sphx_glr_auto_examples_parallel_distributed_backend_simple.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Using Dask for single-machine parallel computing</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/parallel/distributed_backend_simple

